@@ -33,6 +33,6 @@ erp3pQbx5rD0cMYJBw3K
 """
 
 
-class TestSignatures(object):
+class TestSignatures:
     def test_verify_script(self):
         assert U.verify_script(SCRIPT, SIGNATURE) is None
